@@ -29,13 +29,12 @@ check_for_errors () {
 
 echo Looking for forbidden instructions in binary image templates
 
-for distro in debian ubuntu centos rhel; do
+for distro in debian ubuntu centos; do
     tmpdir=$(mktemp -d kolla-templates.XXXXXX --tmpdir)
     generate_templates
     check_for_errors "gem .*install"
     check_for_errors "pip .*install"
     check_for_errors "npm .*install"
-    check_for_errors "sensu-install"
     check_for_errors "git .*clone"
     check_for_errors "wget"
     check_for_errors "curl"
